# jupyterlab_autoversion
Automatically version jupyter notebooks in JupyterLab

[![Build Status](https://github.com/timkpaine/jupyterlab_autoversion/workflows/Build%20Status/badge.svg?branch=main)](https://github.com/timkpaine/jupyterlab_autoversion/actions?query=workflow%3A%22Build+Status%22)
[![codecov](https://codecov.io/gh/timkpaine/jupyterlab_autoversion/branch/main/graph/badge.svg)](https://codecov.io/gh/timkpaine/jupyterlab_autoversion)
[![PyPI](https://img.shields.io/pypi/l/jupyterlab_autoversion.svg)](https://pypi.python.org/pypi/jupyterlab_autoversion)
[![PyPI](https://img.shields.io/pypi/v/jupyterlab_autoversion.svg)](https://pypi.python.org/pypi/jupyterlab_autoversion)
[![npm](https://img.shields.io/npm/v/jupyterlab_autoversion.svg)](https://www.npmjs.com/package/jupyterlab_autoversion)


## Save every notebook revision
Enhanced checkpoints, versioned and persistent between restarts on every save

![](https://raw.githubusercontent.com/timkpaine/jupyterlab_autoversion/main/docs/example.gif)


## Install

```bash
pip install jupyterlab_autoversion
jupyter lab build
```


## Development

See [CONTRIBUTING.md](./CONTRIBUTING.md) for guidelines.


## License

This software is licensed under the Apache 2.0 license. See the
[LICENSE](LICENSE) file for details.
